import request from '@/router/axios'

// 分页查询-任务成员
export function showMember(query) {
	return request({
		url: '/admin/wmimportuser/page',
		method: 'get',
		params: query
	})
}

// 分页查询-举证上传
export function showUpload(query) {
	return request({
		url: '/admin/wmtask/list',
		method: 'get',
		params: query
	})
}

// 添加成员
export function wmImportuser(obj) {
	return request({
		url: '/admin/wmimportuser',
		method: 'post',
		data: obj
	})
}

// 编辑成员
export function editUser(obj) {
	return request({
	  url: '/admin/wmimportuser',
	  method: 'put',
	  data: obj
	})
  }

// 编辑成员
export function delUser(id) {
  return request({
    url: '/admin/wmimportuser/del/' + id,
    method: 'get',
  })
}
// 关联任务积分包
export function getRelationScoreList(query) {
  return request({
    url: '/admin/wmscorepackage/getRelationScoreList',
    method: 'get',
    params:query
  })
}

// 编辑回显
export function getScorePackagePageById(query) {
  return request({
    url: '/admin/wmscorepackage/getScorePackagePageById',
    method: 'get',
    params: query
  })
}

// 有效任务类型
export function getTaskTypeTree(query) {
  return request({
    url: '/admin/wmtasktype/getTaskTypeTree',
    method: 'get',
    params: query
  })
}

// 添加成员
export function saveTaskSettle(obj) {
  return request({
    url: '/admin/wmtask/saveTaskSettle',
    method: 'post',
    data: obj
  })
}


// 添加成员
export function updateTaskSettle(obj) {
  return request({
    url: '/admin/wmtask/updateTaskSettle',
    method: 'post',
    data: obj
  })
}


// 举证上传-动态列表
export function selectSettleTask(query) {
  return request({
    url: '/admin/wmtask/selectSettleTask',
    method: 'get',
    params: query
  })
}

